<?php
namespace OrganizationsManagement\Controller;
use OrganizationsManagement\Util\Utilities;
use Zeedhi\Framework\Controller\Simple;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DataSource;
use OrganizationsManagement\Service;
use OrganizationsManagement\Util\InstanceProvider;
use OrganizationsManagement\Traits\TResponse;

class Operador extends Simple {
    
    use TResponse;

    public function gerarSenha(DTO\Request\DataSet $requisicao, DTO\Response $resposta){
        try {
            $detalhes = $requisicao->getDataSet()->getRows()[0];
            $idOrganizacao = empty($detalhes['NRORG']) ? null : $detalhes['NRORG'];
            $emailOperador = empty($detalhes['DSEMAILOPER']) ? null : $detalhes['DSEMAILOPER'];
            InstanceProvider::getService()->getOperador()->redefineSenha($idOrganizacao, $emailOperador);
            $resposta->addMessage(new DTO\Response\Message("Senha gerada com sucesso e enviada para o e-mail do operador."));
        } catch(\Exception $ex){
            $resposta->setError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function findAllOperadores(DTO\Request $request, DTO\Response $response)
    {
        try {
            $data = InstanceProvider::getService()->getOperador()->findAllOperadores();
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findOperadoresPorCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
        	$cdCliente = $request->getParameter('CDCLIENTE');
            $data = InstanceProvider::getService()->getOperador()->findOperadoresPorCliente($cdCliente);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function findRelacionarOperadoresComCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
        	$cdcliente = $request->getParameter('CDCLIENTE');
            $data = InstanceProvider::getService()->getOperador()->findRelacionarOperadoresComCliente($cdcliente);
            $this->sendResponse($data, 200);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }

    public function saveRelacionarOperadoreComCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadorService = InstanceProvider::getService()->getOperador();
            $operadores = $request->getParameter('operadores');
            $cdcliente = $request->getParameter('cdcliente');
            $idtpoperclie = $request->getParameter('idtpoperclie');
            $nrpriopercli = $request->getParameter('nrpriopercli');
            $operadorService->saveRelacionarOperadoreComCliente($operadores, $cdcliente, $idtpoperclie, $nrpriopercli);
        } catch (\Exception $ex){
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function deleteRelacionarOperadoreComCliente(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadorService = InstanceProvider::getService()->getOperador();
            $opearadores = $request->getParameters();
            $operadorService->deleteRelacionarOperadoreComCliente($opearadores);
        } catch (\Exception $ex) {
            $response->setCriticalError(new Error($ex->getMessage(), $ex->getCode()));
        }
    }

    public function saveOperadorMaster(DTO\Request $request, DTO\Response $response)
    {
        try {
            $operadorService = InstanceProvider::getService()->getOperador();
            $operadores = $request->getParameter('operadores');
            $operadorService->saveOperadorMaster($operadores);
        } catch (\Exception $ex){
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
        }
    }
}
